###Description
PyCLBLAS is a wrapper for the clBLAS library.  This module can be used to call BLAS routines on OpenCL enabled devices from Python.

###Resources
* Documentation is available at [ReadTheDocs.org](https://pyclblas.readthedocs.io/en/latest/index.html)
* Linux binaries and source packages are available at the project's [PyPI page](https://pypi.python.org/pypi/pyclblas/)

###Installation:
* sudo pip install pyclblas
* Installation Requirements (Non-Python):
    * OpenCL
    * [clBLAS](https://github.com/clMathLibraries/clBLAS) (Available in Ubuntu repos)
    * [SWIG](https://www.swig.org/) (Available in Ubuntu and CentOS repos)
* Installation Requirements (Python Packages):
    * [pyopencl](https://github.com/pyopencl/pyopencl/)
    * [numpy](https://github.com/numpy/numpy)
